about summary refs log tree commit diff
diff options
context:
space:
mode:
authorMatthias Krüger <matthias.krueger@famsik.de>2023-10-16 19:10:49 +0200
committerGitHub <noreply@github.com>2023-10-16 19:10:49 +0200
commit6f9df29ad5d6e77323fd070d121e9a7c834f7324 (patch)
tree84c544e800a00ff9cf6489f36022b1d61b6438c9
parent14663e09b7d316a5d48ae46eab46e4f4fedd9e8c (diff)
parent92ab93fcb555d30cc88a994c98ba28244f0553f8 (diff)
downloadrust-6f9df29ad5d6e77323fd070d121e9a7c834f7324.tar.gz
rust-6f9df29ad5d6e77323fd070d121e9a7c834f7324.zip
Rollup merge of #116430 - onur-ozkan:vendoring-in-tarball-sources, r=clubby789
vendoring in tarball sources

fixes #94782
-rw-r--r--src/bootstrap/builder/tests.rs1
-rw-r--r--src/bootstrap/dist.rs14
2 files changed, 9 insertions, 6 deletions
diff --git a/src/bootstrap/builder/tests.rs b/src/bootstrap/builder/tests.rs
index 80e66622e8b..0294102286e 100644
--- a/src/bootstrap/builder/tests.rs
+++ b/src/bootstrap/builder/tests.rs
@@ -22,7 +22,6 @@ fn configure_with_args(cmd: &[String], host: &[&str], target: &[&str]) -> Config
         ..Config::parse(&["check".to_owned()])
     });
     submodule_build.update_submodule(Path::new("src/doc/book"));
-    submodule_build.update_submodule(Path::new("src/tools/rust-analyzer"));
     config.submodules = Some(false);
 
     config.ninja_in_file = false;
diff --git a/src/bootstrap/dist.rs b/src/bootstrap/dist.rs
index 05556d2f679..7bb59e5a611 100644
--- a/src/bootstrap/dist.rs
+++ b/src/bootstrap/dist.rs
@@ -1002,11 +1002,15 @@ impl Step for PlainSourceTarball {
             channel::write_commit_info_file(&plain_dst_src, info);
         }
 
-        // If we're building from git sources, we need to vendor a complete distribution.
-        if builder.rust_info().is_managed_git_subrepository() {
-            // Ensure we have the submodules checked out.
-            builder.update_submodule(Path::new("src/tools/cargo"));
-            builder.update_submodule(Path::new("src/tools/rust-analyzer"));
+        // If we're building from git or tarball sources, we need to vendor
+        // a complete distribution.
+        if builder.rust_info().is_managed_git_subrepository()
+            || builder.rust_info().is_from_tarball()
+        {
+            if builder.rust_info().is_managed_git_subrepository() {
+                // Ensure we have the submodules checked out.
+                builder.update_submodule(Path::new("src/tools/cargo"));
+            }
 
             // Vendor all Cargo dependencies
             let mut cmd = Command::new(&builder.initial_cargo);